@@ -1,6 +1,7 @@
 package Games::TicTacToe;
 
-$Games::TicTacToe::VERSION = '0.20';
+$Games::TicTacToe::VERSION = '0.21';
+$Games::TicTacToe::AUTHOR  = 'cpan:MANWAR';
 
 =head1 NAME
 
@@ -8,7 +9,7 @@ Games::TicTacToe - Interface to the TicTacToe (nxn) game.
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
@@ -17,14 +18,14 @@ use Data::Dumper;
 use Games::TicTacToe::Move;
 use Games::TicTacToe::Board;
 use Games::TicTacToe::Player;
-use Games::TicTacToe::Params qw($Board $Player $Players);
+use Games::TicTacToe::Params qw(Board Player Players);
 
 use Moo;
 use namespace::clean;
 
-has 'board'   => (is => 'rw', isa => $Board);
-has 'current' => (is => 'rw', isa => $Player,  default   => sub { return 'H'; });
-has 'players' => (is => 'rw', isa => $Players, predicate => 1);
+has 'board'   => (is => 'rw', isa => Board);
+has 'current' => (is => 'rw', isa => Player,  default   => sub { return 'H'; });
+has 'players' => (is => 'rw', isa => Players, predicate => 1);
 has 'size'    => (is => 'ro', default   => sub { return 3 });
 has 'winner'  => (is => 'rw', predicate => 1, clearer => 1);
 
