@@ -1,6 +1,7 @@
 package Games::TicTacToe::Player;
 
-$Games::TicTacToe::Player::VERSION = '0.20';
+$Games::TicTacToe::Player::VERSION = '0.21';
+$Games::TicTacToe::Player::AUTHOR  = 'cpan:MANWAR';
 
 =head1 NAME
 
@@ -8,19 +9,19 @@ Games::TicTacToe::Player - Interface to the TicTacToe game's player.
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
 use 5.006;
 use Data::Dumper;
-use Games::TicTacToe::Params qw($Type $Symbol);
+use Games::TicTacToe::Params qw(Type Symbol);
 
 use Moo;
 use namespace::clean;
 
-has 'type'   => (is => 'ro', isa => $Type,   default => sub { return 'H' }, required => 1);
-has 'symbol' => (is => 'ro', isa => $Symbol, default => sub { return 'X' }, required => 1);
+has 'type'   => (is => 'ro', isa => Type,   default => sub { return 'H' }, required => 1);
+has 'symbol' => (is => 'ro', isa => Symbol, default => sub { return 'X' }, required => 1);
 
 =head1 DESCRIPTION
 
